/**
  *  IMPORTANT NOTE!
  *  The symbol VECT_TAB_SRAM needs to be defined when building the project
  *  if code has been located to RAM and interrupts are used.
  *  Otherwise the interrupt table located in flash will be used.
  *  See also the <system_*.c> file and how the SystemInit() function updates
  *  SCB->VTOR register.
  *  E.g.  SCB->VTOR = 0x20000000;
  */

#include <stm32f10x.h>

extern "C" void TIM6_DAC_IRQHandler()
{
	if(TIM6->SR&TIM_SR_UIF)
	{
		TIM6->SR&=~TIM_SR_UIF;

		// LED TOGGLE
		if(GPIOC->ODR&GPIO_ODR_ODR9)
			GPIOC->BRR=GPIO_BRR_BR9;
		else
			GPIOC->BSRR=GPIO_BSRR_BS9;
	}
}

int main()
{
	RCC->APB1ENR|=RCC_APB1ENR_TIM6EN;
	RCC->APB2ENR|=RCC_APB2ENR_IOPCEN;

	// PC9    
	//   , .  2 
	// (CNF9: 00, MODE9: 10)
	GPIOC->CRH=GPIOC->CRH&
			~(GPIO_CRH_CNF9|GPIO_CRH_MODE9)|
			GPIO_CRH_MODE9_1;

	NVIC_SetPriority(TIM6_DAC_IRQn, (1<<__NVIC_PRIO_BITS)-1);
	NVIC_EnableIRQ(TIM6_DAC_IRQn);

	//     
	//   4  (   24 ).
	//   ""  2 
	// (1       ).
	TIM6->ARR=0xFFFF;
	TIM6->PSC=91;
	TIM6->CR1|=TIM_CR1_URS;
	TIM6->EGR|=TIM_EGR_UG;
	TIM6->DIER|=TIM_DIER_UIE;

	TIM6->CR1|=TIM_CR1_CEN;

	while(true);
}
